// Template application. Copyright (C) 1996-1998 Santa Fe Institute.
// This library is distributed without any warranty; without even the
// implied warranty of merchantability or fitness for a particular purpose.
// See file LICENSE for details and terms of copying.

// Template main.m: this particular "simulation" just creates an object
// that spins its own counter, prints out numbers occasionally. Take that
// code out and add in your own simulation needs.
// Pay special attention to the word "MODIFY", that's for you to customize.

#import "TemplateObserverSwarm.h"

int
main (int argc, const char **argv)
{
  TemplateObserverSwarm *observerSwarm;

  initSwarm (argc, argv);

#if 0
  [globalTkInterp eval: "bitmap define testmap {{16 16} {
   0x00, 0x00, 0x00, 0x00, 0x04, 0x80, 0x08, 0x40, 0x90, 0x27, 0x60, 0x18,
   0x60, 0x18, 0x90, 0x24, 0x10, 0x23, 0x10, 0x23, 0x90, 0x24, 0x60, 0x18,
   0x60, 0x18, 0x90, 0x27, 0x08, 0x40, 0x04, 0x80}}"] ;
#endif

  observerSwarm = [TemplateObserverSwarm create: globalZone];
  [observerSwarm buildObjects];
  [observerSwarm buildActions];
  [observerSwarm activateIn: nil];
  [observerSwarm go];

  return 0;
}
